@@ -73,6 +73,8 @@ KdeConnectKcm::KdeConnectKcm(QWidget *parent, const QVariantList&)
             this, SLOT(unpair()));
     connect(kcmUi->ping_button, SIGNAL(pressed()),
             this, SLOT(sendPing()));
+    connect(kcmUi->browse_button, SIGNAL(clicked(bool)),
+            this, SLOT(browseFilesystem()));
 
 }
 
@@ -252,3 +254,8 @@ void KdeConnectKcm::sendPing()
     currentDevice->sendPing();
 }
 
+void KdeConnectKcm::browseFilesystem()
+{
+    if (!currentDevice) return;
+    SftpDbusInterface(currentDevice->id(), this).startBrowsing();
+}
